#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
#include <cmath>
#include <unordered_map>
#include <set>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<long long>(x.size())

#define double long double

using ll = long long;

struct LinearFunc {
    double K, B;
    LinearFunc(double k = 0.0, double b = 1e18) : K(k), B(b) {}
    double operator() (double X) {
        return K * X + B;
    }
};

vector<double> coords;

struct LCT {
    int left, right;
    LCT* lv, * rv;
    LinearFunc func;
    LCT(int l = 0, int r = 1) : left(l), right(r), lv(nullptr), rv(nullptr), func() {
        build();
    }
    void build() {
        if (left + 1 >= right) {
            return;
        }
        int mid = (left + right) / 2;
        lv = new LCT(left, mid);
        rv = new LCT(mid, right);
    }
    void add(LinearFunc gfunc) {
        int mid = (left + right) / 2;
        if (gfunc(coords[mid]) < func(coords[mid])) {
            swap(gfunc, func);
        }
        if (lv && gfunc(coords[left]) < func(coords[left])) {
            lv->add(gfunc);
        }
        else if (rv && gfunc(coords[right - 1]) < func(coords[right - 1])) {
            rv->add(gfunc);
        }
    }
    double get(double X) {
        int mid = (left + right) / 2;
        if (lv && X < coords[mid]) {
            return min(func(X), lv->get(X));
        } 
        if (rv && X >= coords[mid]) {
            return min(func(X), rv->get(X));
        }
        return func(X);
    }
};

void solve() {
    int n, m; double c; cin >> n >> m >> c;
    vector<pair<double, double>> stations(n);
    for (auto& p : stations) {
        cin >> p.first >> p.second;
        coords.push_back(p.first);
    }
    coords.push_back(m);
    LCT chao(0, n + 1);
    chao.add(LinearFunc(0, 0));
    vector<double> dp(n);
    for (int i = 0; i < n; i++) {
        double cur_x = stations[i].first, time = stations[i].second;
        dp[i] = chao.get(cur_x) + cur_x * cur_x / c + time;
        chao.add(LinearFunc(- 2.0 * cur_x / c, dp[i] + cur_x * cur_x / c));
    }
    cout.precision(15);
    cout << fixed << chao.get(m) + m * m / c;
}

int main() {
    cin.tie(nullptr)->sync_with_stdio(false);
    int t = 1;
    while (t--) {
        solve();
    }
    return 0;
}