#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>
#include <string>
#include <cmath>
#include <unordered_map>
#include <set>
using namespace std;

#define all(x) x.begin(), x.end()
#define sz(x) static_cast<long long>(x.size())

#define lng long long

using ll = long long;

struct LinearFunc {
    lng K, B;
    LinearFunc(lng k = 0.0, lng b = 1e18) : K(k), B(b) {}
    lng operator() (lng X) {
        return K * X + B;
    }
};

vector<lng> coords;

struct LCT {
    int left, right;
    LCT* lv, * rv;
    LinearFunc func;
    LCT(int l = 0, int r = 1) : left(l), right(r), lv(nullptr), rv(nullptr), func() {
        build();
    }
    void build() {
        if (left + 1 >= right) {
            return;
        }
        int mid = (left + right) / 2;
        lv = new LCT(left, mid);
        rv = new LCT(mid, right);
    }
    void add(LinearFunc gfunc) {
        int mid = (left + right) / 2;
        if (gfunc(coords[mid]) < func(coords[mid])) {
            swap(gfunc, func);
        }
        if (lv && gfunc(coords[left]) < func(coords[left])) {
            lv->add(gfunc);
        }
        else if (rv && gfunc(coords[right - 1]) < func(coords[right - 1])) {
            rv->add(gfunc);
        }
    }
    lng get(lng X) {
        int mid = (left + right) / 2;
        if (lv && X < coords[mid]) {
            return min(func(X), lv->get(X));
        } 
        if (rv && X >= coords[mid]) {
            return min(func(X), rv->get(X));
        }
        return func(X);
    }
};

void solve() {
    int n, m; lng c; cin >> n >> m >> c;
    vector<pair<lng, lng>> stations(n);
    for (auto& p : stations) {
        cin >> p.first >> p.second;
        coords.push_back(p.first);
    }
    coords.push_back(m);
    LCT chao(0, n + 1);
    chao.add(LinearFunc(0, 0));
    vector<lng> dp(n);
    for (int i = 0; i < n; i++) {
        lng cur_x = stations[i].first, time = stations[i].second;
        dp[i] = chao.get(cur_x) + cur_x * cur_x + time * c;
        chao.add(LinearFunc(- 2.0 * cur_x, dp[i] + cur_x * cur_x));
    }
    cout.precision(15);
    cout << fixed << static_cast<double>(chao.get(m) + m * m) / static_cast<double>(c);
}

int main() {
    cin.tie(nullptr)->sync_with_stdio(false);
    int t = 1;
    while (t--) {
        solve();
    }
    return 0;
}
