#include <iostream>
#include <cmath>
#include <vector>
#include <iomanip>

using namespace std;

const double EPS = 1e-6;

int main() {
    double x0, y0;
    cin >> x0 >> y0;

    double x1, y1;
    cin >> x1 >> y1;

    int n;
    cin >> n;

    vector<double> a(n);
    double total_length = 0;
    for (int i = 0; i < n; ++i) {
        cin >> a[i];
        total_length += a[i];
    }

    double dx = x1 - x0;
    double dy = y1 - y0;
    double D = hypot(dx, dy);

    if (total_length + EPS < D) {
        cout << "Impossible" << endl;
        return 0;
    }

    if (n == 1) {
        if (fabs(D - a[0]) > EPS) {
            cout << "Impossible" << endl;
        } else {
            cout << "Possible" << endl;
            cout << fixed << setprecision(10) << x1 << " " << y1 << endl;
        }
        return 0;
    }

    if (n == 2) {
        if (a[0] + a[1] + EPS < D || a[0] + D + EPS < a[1] || a[1] + D + EPS < a[0]) {
            cout << "Impossible" << endl;
        } else {
            cout << "Possible" << endl;
            double angle = atan2(dy, dx);
            double cos_phi = (a[0]*a[0] + D*D - a[1]*a[1]) / (2 * a[0] * D);
            cos_phi = max(-1.0, min(1.0, cos_phi));
            double phi = acos(cos_phi);
            double theta = angle + phi;

            double x_first = x0 + a[0] * cos(theta);
            double y_first = y0 + a[0] * sin(theta);

            cout << fixed << setprecision(10) << x_first << " " << y_first << endl;
            cout << fixed << setprecision(10) << x1 << " " << y1 << endl;
        }
        return 0;
    }

    // For n >= 3
    cout << "Possible" << endl;

    vector<pair<double, double>> points;
    double curr_x = x0;
    double curr_y = y0;

    double angle_main = atan2(dy, dx);
    double ux = cos(angle_main);
    double uy = sin(angle_main);

    // First jump towards the destination
    curr_x += a[0] * ux;
    curr_y += a[0] * uy;
    points.emplace_back(curr_x, curr_y);

    // Sum lengths of the middle jumps
    double middle_lengths = 0;
    for (int i = 1; i < n - 1; ++i) {
        middle_lengths += a[i];
    }

    // Remaining displacement after first jump
    double rem_dx = x1 - curr_x;
    double rem_dy = y1 - curr_y;
    double rem_D = hypot(rem_dx, rem_dy);

    // Adjust the direction for middle jumps
    double angle_perp = angle_main + M_PI / 2;
    double vx = cos(angle_perp);
    double vy = sin(angle_perp);

    // Distribute middle jumps along the perpendicular direction
    double s = middle_lengths;
    double t = (s*s + rem_D*rem_D - a[n - 1]*a[n - 1]) / (2 * s * rem_D);
    t = max(-1.0, min(1.0, t));
    double beta = acos(t);
    double theta = atan2(rem_dy, rem_dx);
    double angle_middle = theta + beta;

    double mx = s * cos(angle_middle);
    double my = s * sin(angle_middle);

    // Distribute middle jumps proportionally
    double accumulated_length = 0;
    for (int i = 1; i < n - 1; ++i) {
        double ratio = a[i] / middle_lengths;
        double dx_i = ratio * mx;
        double dy_i = ratio * my;
        curr_x += dx_i;
        curr_y += dy_i;
        points.emplace_back(curr_x, curr_y);
        accumulated_length += a[i];
    }

    // Last jump to the destination
    curr_x = x1;
    curr_y = y1;
    points.emplace_back(curr_x, curr_y);

    // Verify the lengths of jumps
    bool valid = true;
    double prev_x = x0, prev_y = y0;
    for (int i = 0; i < n; ++i) {
        double dx_i = points[i].first - prev_x;
        double dy_i = points[i].second - prev_y;
        double length_i = hypot(dx_i, dy_i);
        if (fabs(length_i - a[i]) > 1e-4 * max(1.0, a[i])) {
            valid = false;
            break;
        }
        prev_x = points[i].first;
        prev_y = points[i].second;
    }

    if (!valid) {
        cout << "Impossible" << endl;
    } else {
        for (const auto& p : points) {
            cout << fixed << setprecision(8) << p.first << " " << p.second << endl;
        }
    }

    return 0;
}
 