#include <iostream>
#include <vector>
#include <set>
#include <algorithm>
#include <iterator>

using namespace std;

void generate_pieces(int length, const vector<int>& cuts, vector<int>& pieces) {
    vector<int> positions = {0};
    positions.insert(positions.end(), cuts.begin(), cuts.end());
    positions.push_back(length);
    for (size_t i = 0; i < positions.size() - 1; ++i) {
        pieces.push_back(positions[i + 1] - positions[i]);
    }
}

int main() {
    int n, m, s;
    cin >> n >> m >> s;

    if (s == n * m) {
        cout << 0 << endl;
        return 0;
    }

    int max_cuts = n + m - 2;

    for (int total_cuts = 1; total_cuts <= max_cuts; ++total_cuts) {
        for (int x_cuts = max(0, total_cuts - (n - 1)); x_cuts <= min(total_cuts, m - 1); ++x_cuts) {
            int y_cuts = total_cuts - x_cuts;
            if (y_cuts > n - 1) {
                continue;
            }

            vector<int> vertical_positions(m - 1);
            iota(vertical_positions.begin(), vertical_positions.end(), 1);
            vector<int> horizontal_positions(n - 1);
            iota(horizontal_positions.begin(), horizontal_positions.end(), 1);

            vector<vector<int>> vertical_cuts_list;
            if (x_cuts > 0) {
                do {
                    vector<int> combination;
                    for (int i = 0; i < vertical_positions.size(); ++i) {
                        if (vertical_positions[i] < m && x_cuts > 0) {
                            combination.push_back(vertical_positions[i]);
                            --x_cuts;
                        }
                    }
                    vertical_cuts_list.push_back(combination);
                } while (next_permutation(vertical_positions.begin(), vertical_positions.end()));
            } else {
                vertical_cuts_list.push_back({});
            }

            vector<vector<int>> horizontal_cuts_list;
            if (y_cuts > 0) {
                do {
                    vector<int> combination;
                    for (int i = 0; i < horizontal_positions.size(); ++i) {
                        if (horizontal_positions[i] < n && y_cuts > 0) {
                            combination.push_back(horizontal_positions[i]);
                            --y_cuts;
                        }
                    }
                    horizontal_cuts_list.push_back(combination);
                } while (next_permutation(horizontal_positions.begin(), horizontal_positions.end()));
            } else {
                horizontal_cuts_list.push_back({});
            }

            for (const auto& v_cuts : vertical_cuts_list) {
                vector<int> widths;
                generate_pieces(m, v_cuts, widths);
                for (const auto& h_cuts : horizontal_cuts_list) {
                    vector<int> heights;
                    generate_pieces(n, h_cuts, heights);

                    vector<int> areas;
                    for (int w : widths) {
                        for (int h : heights) {
                            areas.push_back(w * h);
                        }
                    }

                    set<int> dp = {0};
                    for (int area : areas) {
                        set<int> new_dp = dp;
                        for (int existing_sum : dp) {
                            int new_sum = existing_sum + area;
                            if (new_sum == s) {
                                cout << total_cuts << endl;
                                return 0;
                            }
                            if (new_sum <= s) {
                                new_dp.insert(new_sum);
                            }
                        }
                        dp = new_dp;
                    }
                }
            }
        }
    }

    cout << max_cuts << endl;
    return 0;
}

