import heapq

def solve():
    # Считываем данные
    n, m, c = map(int, input().split())
    
    # Считываем заправочные станции
    stations = []
    for _ in range(n):
        x, t = map(int, input().split())
        stations.append((x, t))
    
    # Добавляем начальную и конечную точки
    stations.append((0, 0))  # Начало пути (Санкт-Петербург)
    stations.append((m, 0))  # Конец пути (Москва)
    
    # Сортируем станции по позициям
    stations.sort()
    
    # Массив для хранения минимального времени для каждой станции
    dp = [float('inf')] * (n + 2)
    dp[0] = 0  # Время для старта из Санкт-Петербурга
    
    # Приоритетная очередь для оптимизации переходов между станциями
    pq = []
    heapq.heappush(pq, (0, 0))  # (время, индекс станции)
    
    # Обрабатываем каждую станцию
    while pq:
        time, idx = heapq.heappop(pq)
        
        # Если уже нашли лучшее время для этой станции, пропускаем
        if time > dp[idx]:
            continue
        
        # Пройдем по всем возможным следующим станциям
        for i in range(idx + 1, n + 2):
            # Расстояние между текущей станцией и станцией i
            dist = stations[i][0] - stations[idx][0]
            # Время для перехода между станциями с учётом расхода топлива
            travel_time = dist / c
            total_time = time + travel_time + stations[i][1]  # Общее время с учётом заправки
            
            # Если нашли меньшее время, обновляем dp и добавляем в очередь
            if total_time < dp[i]:
                dp[i] = total_time
                heapq.heappush(pq, (total_time, i))
    
    # Выводим минимальное время для достижения Москвы
    print(f"{dp[n+1]:.10f}")

