#include <iostream>
#include <cmath>
#include <vector>

using namespace std;

const double EPS = 1e-7;

struct Point {
    double x, y;
    
    Point() : x(0), y(0) {}
    Point(double x, double y) : x(x), y(y) {}
    
    // Расстояние между двумя точками
    double distTo(const Point& p) const {
        return sqrt((x - p.x) * (x - p.x) + (y - p.y) * (y - p.y));
    }
    
    // Перемещение на вектор (dx, dy)
    void move(double dx, double dy) {
        x += dx;
        y += dy;
    }
};

int main() {
    // Чтение данных
    int x0, y0, x1, y1, n;
    cin >> x0 >> y0 >> x1 >> y1 >> n;
    
    vector<int> a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];
    }
    
    // Стартовая и конечная точки
    Point start(x0, y0), end(x1, y1);
    
    // Общая длина пути
    double totalDistance = start.distTo(end);
    
    // Проверим, можем ли вообще двигаться в нужную точку с помощью заданных прыжков
    double totalJumpLength = 0;
    for (int i = 0; i < n; ++i) {
        totalJumpLength += a[i];
    }
    
    if (fabs(totalDistance - totalJumpLength) > EPS) {
        cout << "Impossible" << endl;
        return 0;
    }
    
    // Для каждого прыжка вычисляем направление
    Point current = start;
    
    // Выводим первую точку, которая совпадает с начальной
    cout << "Possible" << endl;
    
    for (int i = 0; i < n; ++i) {
        // Направление от текущей точки к конечной
        double dx = end.x - current.x;
        double dy = end.y - current.y;
        double dist = sqrt(dx * dx + dy * dy);
        
        // Нормализуем вектор (dx, dy) и перемещаемся на нужную длину
        dx /= dist;
        dy /= dist;
        
        // Перемещаемся на ai шагов
        current.move(dx * a[i], dy * a[i]);
        
        // Выводим текущую точку
        cout.precision(6);
        cout << fixed << current.x << " " << current.y << endl;
    }
    
    return 0;
}
