#include <iostream>
#include <cmath>
#include <vector>
#include <tuple>
#include <climits>

using namespace std;

// Вычисляем расстояние от точки (x, y) до прямой Ax + By + C = 0
double point_to_line_distance(int x, int y, int A, int B, int C) {
    return abs(A * x + B * y + C) / sqrt(A * A + B * B);
}

// Проверяем прямую через две точки и возвращаем суммарное расстояние до всех точек
double evaluate_line(int x1, int y1, int x2, int y2, vector<pair<int, int>> &points) {
    // Уравнение прямой через (x1, y1) и (x2, y2): Ax + By + C = 0
    int A = y2 - y1;
    int B = x1 - x2;
    int C = x2 * y1 - x1 * y2;

    double total_distance = 0;
    for (auto &[px, py] : points) {
        total_distance += point_to_line_distance(px, py, A, B, C);
    }

    return total_distance;
}

int main() {
    int x1, y1, x2, y2, x3, y3;
    cin >> x1 >> y1 >> x2 >> y2 >> x3 >> y3;

    vector<pair<int, int>> points = {{x1, y1}, {x2, y2}, {x3, y3}};
    vector<tuple<int, int, int, int>> candidates = {
        {x1, y1, x2, y2},
        {x1, y1, x3, y3},
        {x2, y2, x3, y3}
    };

    double min_distance = INT_MAX;
    tuple<int, int, int, int> best_line;

    // Проверяем каждую пару точек
    for (auto &[ax, ay, bx, by] : candidates) {
        double distance = evaluate_line(ax, ay, bx, by, points);
        if (distance < min_distance) {
            min_distance = distance;
            best_line = {ax, ay, bx, by};
        }
    }

    // Выводим результат
    auto [rx1, ry1, rx2, ry2] = best_line;
    cout << rx1 << " " << ry1 << " " << rx2 << " " << ry2 << endl;

    return 0;
}



