#include <iostream>
#include <vector>
#include <set>
#include <unordered_map>
#include <algorithm>

using namespace std;

vector<long long> process_queries(int n, const vector<tuple<char, int, int, int>>& queries) {
    unordered_map<int, set<pair<int, int>>> color_edges;
    unordered_map<int, unordered_map<int, int>> vertex_color_degree;
    unordered_map<int, bool> is_superior_color;
    long long total_beauty = 0;
    vector<long long> result;

    for (const auto& query : queries) {
        char action;
        int v, u, c;
        tie(action, v, u, c) = query;

        if (v > u) swap(v, u);
        
        if (action == '+') {
            color_edges[c].insert({v, u});
            vertex_color_degree[c][v]++;
            vertex_color_degree[c][u]++;
            
            if (is_superior_color[c]) {
                total_beauty -= color_edges[c].size() - 1;
            }
            is_superior_color[c] = all_of(vertex_color_degree[c].begin(), vertex_color_degree[c].end(), [](const auto& pair) {
                return pair.second <= 1;
            });
            if (is_superior_color[c]) {
                total_beauty += color_edges[c].size();
            }

        } else if (action == '-') {
            color_edges[c].erase({v, u});
            vertex_color_degree[c][v]--;
            vertex_color_degree[c][u]--;

            if (is_superior_color[c]) {
                total_beauty -= color_edges[c].size() + 1;
            }
            is_superior_color[c] = all_of(vertex_color_degree[c].begin(), vertex_color_degree[c].end(), [](const auto& pair) {
                return pair.second <= 1;
            });
            if (is_superior_color[c]) {
                total_beauty += color_edges[c].size();
            }
        }

        result.push_back(total_beauty);
    }

    return result;
}

int main() {
    int n, q;
    cin >> n >> q;
    vector<tuple<char, int, int, int>> queries(q);

    for (int i = 0; i < q; ++i) {
        char action;
        int v, u, c;
        cin >> action >> v >> u >> c;
        queries[i] = make_tuple(action, v, u, c);
    }

    vector<long long> results = process_queries(n, queries);
    for (long long res : results) {
        cout << res << endl;
    }

    return 0;
}