def generate_tetrominoes(n):
    if n < 3:
        return -1

    grid = [[0] * n for _ in range(n)]
    directions = [(-1, 0), (1, 0), (0, -1), (0, 1)]
    shapes = [] 

    def is_valid_shape(shape):
        for existing in shapes:
            if are_shapes_equivalent(existing, shape):
                return False
        return True

    def are_shapes_equivalent(shape1, shape2):
        transformations = [
            lambda x, y: (x, y), lambda x, y: (y, x),
            lambda x, y: (-x, y), lambda x, y: (x, -y),
            lambda x, y: (-x, -y), lambda x, y: (-y, x),
            lambda x, y: (y, -x), lambda x, y: (-y, -x)
        ]
        norm1 = normalize_shape(shape1)
        for transform in transformations:
            transformed = normalize_shape([transform(x, y) for x, y in shape2])
            if norm1 == transformed:
                return True
        return False

    def normalize_shape(shape):
        min_x = min(x for x, y in shape)
        min_y = min(y for x, y in shape)
        return sorted((x - min_x, y - min_y) for x, y in shape)

    def bfs_fill(start_x, start_y, num):
        queue = deque([(start_x, start_y)])
        shape = [(start_x, start_y)]
        grid[start_x][start_y] = num

        while queue and len(shape) < n:
            x, y = queue.popleft()
            for dx, dy in directions:
                nx, ny = x + dx, y + dy
                if 0 <= nx < n and 0 <= ny < n and grid[nx][ny] == 0:
                    grid[nx][ny] = num
                    shape.append((nx, ny))
                    queue.append((nx, ny))
                    if len(shape) == n:
                        break
        return shape

    for num in range(1, n + 1):
        for i in range(n):
            for j in range(n):
                if grid[i][j] == 0:
                    shape = bfs_fill(i, j, num)
                    if len(shape) == n and is_valid_shape(shape):
                        shapes.append(shape)
                    else:
                        return -1

    return grid

n = int(input())
result = generate_tetrominoes(n)
if result == -1:
    print(-1)
else:
    for row in result:
        print(' '.join(map(str, row)))
from collections import deque

def normalize_shape(shape):
    min_x = min(x for x, y in shape)
    min_y = min(y for x, y in shape)
    normalized = sorted((x - min_x, y - min_y) for x, y in shape)
    return tuple(normalized)

def generate_transformations(shape):
    transformations = []
    for flip_x in [1, -1]: 
        for flip_y in [1, -1]: 
            for _ in range(4): 
                shape = [(y * flip_x, -x * flip_y) for x, y in shape]
                transformations.append(normalize_shape(shape))
    return set(transformations)

def is_unique(new_shape, existing_shapes):
    new_transformations = generate_transformations(new_shape)
    for shape in existing_shapes:
        if shape in new_transformations:
            return False
    return True

def bfs_find_shape(grid, start_x, start_y, label, n):
    directions = [(-1, 0), (1, 0), (0, -1), (0, 1)]
    queue = deque([(start_x, start_y)])
    shape = [(start_x, start_y)]
    grid[start_x][start_y] = label

    while queue and len(shape) < n:
        x, y = queue.popleft()
        for dx, dy in directions:
            nx, ny = x + dx, y + dy
            if 0 <= nx < len(grid) and 0 <= ny < len(grid) and grid[nx][ny] == 0:
                grid[nx][ny] = label
                shape.append((nx, ny))
                queue.append((nx, ny))
                if len(shape) == n:
                    break
    return shape if len(shape) == n else None

def generate_tetrominoes(n):
    if n < 3:
        return -1 

    grid = [[0] * n for _ in range(n)]
    existing_shapes = set()

    label = 1
    for i in range(n):
        for j in range(n):
            if grid[i][j] == 0:
                shape = bfs_find_shape(grid, i, j, label, n)
                if shape:
                    normalized_shape = normalize_shape(shape)
                    if is_unique(normalized_shape, existing_shapes):
                        existing_shapes.add(normalized_shape)
                        label += 1
                        if label > n:
                            break
                    else:
                        return -1
                else:
                    return -1
        if label > n:
            break

    if label <= n:
        return -1

    return grid

n = int(input())
result = generate_tetrominoes(n)
if result == -1:
    print(-1)
else:
    for row in result:
        print(" ".join(map(str, row)))