def can_reach_with_speed(v, n, m, c, stations):
    # Time taken to drive and refuel
    current_fuel = c
    total_time = 0
    prev_position = 0

    for i in range(n):
        xi, ti = stations[i]

        # Distance to the current station
        dist = xi - prev_position
        fuel_needed = dist * v

        if fuel_needed > current_fuel:
            # If fuel is insufficient, refuel at the previous station
            total_time += ti
            current_fuel = c  # Full tank after refueling

        # Deduct the fuel needed to reach the station
        current_fuel -= fuel_needed
        total_time += dist / v  # Driving time to the station

        prev_position = xi

    # Finally, check if we can reach Moscow from the last station or Saint Petersburg
    dist_to_moscow = m - prev_position
    fuel_needed = dist_to_moscow * v

    if fuel_needed > current_fuel:
        # Refuel before the final leg
        total_time += stations[-1][1]
        current_fuel = c

    total_time += dist_to_moscow / v  # Time to Moscow from the last station or start

    return total_time

def solve(n, m, c, stations):
    # Binary search for the minimum possible total time
    lo, hi = 1.0, m
    best_time = float('inf')

    while hi - lo > 1e-7:  # We need precision to 10^-6
        mid = (lo + hi) / 2
        total_time = can_reach_with_speed(mid, n, m, c, stations)

        best_time = min(best_time, total_time)
        
        # Adjust the search range based on whether a lower speed can work
        lo = mid if total_time > best_time else lo
        hi = mid if total_time < best_time else hi

    return best_time

# Input Parsing
n, m, c = map(int, input().split())
stations = []
for _ in range(n):
    xi, ti = map(int, input().split())
    stations.append((xi, ti))

# Call the solve function
result = solve(n, m, c, stations)

# Output the result with the necessary precision
print(f"{result:.6f}")
