from collections import defaultdict

def graph_beauty(n, q, queries):
    edges = defaultdict(set)  # edges[c]: set of edges of color c
    degree = defaultdict(lambda: defaultdict(int))  # degree[v][c]: edges of color c connected to vertex v
    beauty = defaultdict(int)  # beauty[c]: total edges of color c
    excellent = set()  # set of excellent colors
    total_beauty = 0

    def update_excellence(c):
        nonlocal total_beauty
        is_excellent = all(degree[v][c] <= 1 for v in degree if c in degree[v])
        if is_excellent and c not in excellent:
            total_beauty += beauty[c]
            excellent.add(c)
        elif not is_excellent and c in excellent:
            total_beauty -= beauty[c]
            excellent.remove(c)

    results = []
    for query in queries:
        op, v, u, c = query
        if op == '+':
            edges[c].add((v, u))
            degree[v][c] += 1
            degree[u][c] += 1
            beauty[c] += 1
            update_excellence(c)
        elif op == '-':
            edges[c].remove((v, u))
            degree[v][c] -= 1
            degree[u][c] -= 1
            beauty[c] -= 1
            update_excellence(c)
        results.append(total_beauty)

    return results

# Input Reading
n, q = map(int, input().split())
queries = []
for _ in range(q):
    line = input().split()
    op = line[0]
    v, u, c = map(int, line[1:])
    queries.append((op, v, u, c))

# Output Results
results = graph_beauty(n, q, queries)
print("\n".join(map(str, results)))
