#include <iostream>
#include <vector>
#include <queue>
#include <algorithm>

using namespace std;

struct Station {
    int distance; // Расстояние до станции
    int time;     // Время на заправку на станции
};

double findMinimumTime(int n, int m, int c, vector<Station>& stations) {
    // Добавляем фиктивную станцию в Москву (расстояние m, время 0)
    stations.push_back({m, 0});
    
    // Сортируем станции по расстоянию
    sort(stations.begin(), stations.end(), [](Station a, Station b) {
        return a.distance < b.distance;
    });

    priority_queue<int> fuelQueue; // Очередь для заправок
    int currentFuel = c;  // Текущее количество топлива
    int currentPosition = 0;  // Текущая позиция
    double totalTime = 0; // Общее время заправок

    for (const auto& station : stations) {
        int distanceToNext = station.distance - currentPosition;

        // Проверяем, можем ли добраться до следующей станции
        while (currentFuel < distanceToNext) {
            if (fuelQueue.empty()) {
                return -1; // Невозможно добраться
            }
            // Заправляемся на лучшей доступной станции
            currentFuel += c;
            totalTime += fuelQueue.top();  // Добавляем время заправки
            fuelQueue.pop();
        }

        // Обновляем параметры
        currentFuel -= distanceToNext; // Расходуем топливо
        currentPosition = station.distance; // Обновляем текущую позицию

        // Добавляем эту станцию в очередь для заправки
        fuelQueue.push(station.time);
    }

    return totalTime;
}

int main() {
    int n, m, c;
    cout << "Введите количество станций (n): ";
    cin >> n;
    cout << "Введите расстояние до Москвы (m): ";
    cin >> m;
    cout << "Введите количество топлива (c): ";
    cin >> c;

    vector<Station> stations(n);

    cout << "Введите данные о станциях (расстояние и время заправки):\n";
    for (int i = 0; i < n; i++) {
        cin >> stations[i].distance >> stations[i].time;
    }

    // Вычисление минимального времени
    double result = findMinimumTime(n, m, c, stations);
    if (result == -1) {
        cout << "Impossible" << endl; // Невозможно добраться
    } else {
        cout << "Минимальное время на заправки: " << result << " минут" << endl;
    }

    return 0;
}
