def colorful_graph(n, q, queries):
    from collections import defaultdict

    # Храним рёбра для каждого цвета
    edges_by_color = defaultdict(set)  # ключ - цвет, значение - множество рёбер

    # Храним степень каждой вершины для каждого цвета
    degree_by_color = defaultdict(lambda: defaultdict(int))  # {цвет: {вершина: степень}}

    # Текущая суммарная красота графа
    total_beauty = 0

    # Результаты после каждого запроса
    results = []

    for query in queries:
        parts = query.split()
        if parts[0] == '+':
            v, u, c = map(int, parts[1:])
            if v > u:  # Упорядочиваем вершины
                v, u = u, v

            # Добавляем ребро
            edges_by_color[c].add((v, u))
            degree_by_color[c][v] += 1
            degree_by_color[c][u] += 1

            # Проверяем, является ли цвет превосходным
            if degree_by_color[c][v] == 1 and degree_by_color[c][u] == 1:
                total_beauty += 1
            elif degree_by_color[c][v] == 2 or degree_by_color[c][u] == 2:
                total_beauty -= 1

        elif parts[0] == '-':
            v, u, c = map(int, parts[1:])
            if v > u:  # Упорядочиваем вершины
                v, u = u, v

            # Удаляем ребро
            edges_by_color[c].remove((v, u))
            degree_by_color[c][v] -= 1
            degree_by_color[c][u] -= 1

            # Проверяем, является ли цвет превосходным
            if degree_by_color[c][v] == 1 and degree_by_color[c][u] == 1:
                total_beauty += 1
            elif degree_by_color[c][v] == 2 or degree_by_color[c][u] == 2:
                total_beauty -= 1

        # Записываем текущую сумму красоты
        results.append(total_beauty)

    return results


# Ввод данных
if __name__ == "__main__":
    n, q = map(int, input().split())
    queries = [input() for _ in range(q)]

    results = colorful_graph(n, q, queries)
    print("\n".join(map(str, results)))
