#include <iostream>
#include <cmath>

using namespace std;

int main() {
    // Input variables
    int c, h;
    cin >> c >> h;
    
    // Basic constraint checks
    if (c < 1 || c > 10000 || h < 1 || h > 10000) {
        cout << -1;
        return 0;
    }
    
    // Height cannot be greater than or equal to hypotenuse
    if (h >= c) {
        cout << -1;
        return 0;
    }
    
    // The height divides the hypotenuse into two parts (x and c-x)
    // From similar triangles: h^2 = x(c-x)
    // This gives us quadratic equation: x^2 - cx + h^2 = 0
    long long discriminant = (long long)c * c - 4LL * h * h;
    
    // If discriminant is negative or zero, no valid solution exists
    if (discriminant <= 0) {
        cout << -1;
        return 0;
    }
    
    // Calculate one of the parts using the quadratic formula
    // x = (c ± √(c^2 - 4h^2)) / 2
    double sqrtDisc = sqrt(discriminant);
    double x1 = (c + sqrtDisc) / 2.0;
    double x2 = (c - sqrtDisc) / 2.0;
    
    // Check if both parts are positive
    if (x1 <= 0 || x2 <= 0) {
        cout << -1;
        return 0;
    }
    
    // Calculate base using Pythagorean theorem
    double base = sqrt(c*c - h*h);
    
    // Final validation: check if base is a real number
    if (isnan(base) || base <= 0) {
        cout << -1;
        return 0;
    }
    
    // Calculate area
    double area = (base * h) / 2.0;
    cout << area;
    
    return 0;
}