#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

// Структура для хранения карты с возможностью переворота
struct Card {
    int front;
    int back;
};

// Функция для нахождения минимального из двух сторон карты
int getMinSide(const Card& card) {
    return min(card.front, card.back);
}

int main() {
    int n;
    cin >> n;

    vector<Card> cards(n);

    // Ввод значений лицевой и обратной сторон
    for (int i = 0; i < n; i++) {
        cin >> cards[i].front;
    }
    for (int i = 0; i < n; i++) {
        cin >> cards[i].back;
    }

    // Сортируем карты по минимальному значению из двух сторон
    sort(cards.begin(), cards.end(), [](const Card &a, const Card &b) {
        return getMinSide(a) < getMinSide(b);
    });

    // Попробуем построить обе стороны в правильном порядке
    vector<int> topOrder, bottomOrder;
    int prevTop = -1, prevBottom = -1;

    for (int i = 0; i < n; i++) {
        int frontSide = cards[i].front;
        int backSide = cards[i].back;

        if (frontSide >= prevTop && backSide >= prevBottom) {
            // Если обе стороны можно использовать без переворота
            topOrder.push_back(frontSide);
            bottomOrder.push_back(backSide);
            prevTop = frontSide;
            prevBottom = backSide;
        } else if (backSide >= prevTop && frontSide >= prevBottom) {
            // Если нужно перевернуть карту
            topOrder.push_back(backSide);
            bottomOrder.push_back(frontSide);
            prevTop = backSide;
            prevBottom = frontSide;
        } else {
            // Если не удается построить обе стороны корректно
            cout << -1 << endl;
            return 0;
        }
    }

    // Вывод результата
    for (int i = 0; i < n; i++) {
        cout << topOrder[i] << " ";
    }
    cout << endl;

    for (int i = 0; i < n; i++) {
        cout << bottomOrder[i] << " ";
    }
    cout << endl;

    return 0;
}
