#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

// Структура для хранения карты
struct Card {
    int front;
    int back;
};

// Функция для проверки возможности упорядочить карты
bool canArrangeCards(vector<Card>& cards) {
    int n = cards.size();
    int prevTop = -1, prevBottom = -1;

    for (int i = 0; i < n; i++) {
        int frontSide = cards[i].front;
        int backSide = cards[i].back;

        // Проверка возможных вариантов расположения карт
        if (frontSide >= prevTop && backSide >= prevBottom) {
            // Обе стороны в порядке
            prevTop = frontSide;
            prevBottom = backSide;
        } else if (backSide >= prevTop && frontSide >= prevBottom) {
            // Переворачиваем карту
            swap(cards[i].front, cards[i].back);
            prevTop = cards[i].front;
            prevBottom = cards[i].back;
        } else {
            // Невозможно упорядочить карты
            return false;
        }
    }
    return true;
}

int main() {
    int n;
    cin >> n;

    vector<Card> cards(n);

    // Ввод значений лицевой и обратной сторон
    for (int i = 0; i < n; i++) {
        cin >> cards[i].front;
    }
    for (int i = 0; i < n; i++) {
        cin >> cards[i].back;
    }

    // Сортируем карты по минимальной стороне
    sort(cards.begin(), cards.end(), [](const Card &a, const Card &b) {
        return min(a.front, a.back) < min(b.front, b.back);
    });

    // Проверка возможности упорядочить карты
    if (canArrangeCards(cards)) {
        // Вывод результата
        for (int i = 0; i < n; i++) {
            cout << cards[i].front << " ";
        }
        cout << endl;
        for (int i = 0; i < n; i++) {
            cout << cards[i].back << " ";
        }
        cout << endl;
    } else {
        // Если порядок не удается построить
        cout << -1 << endl;
    }

    return 0;
}
