from collections import deque

def normalize(shape):
    """Нормализует форму: приводит координаты к каноничному виду."""
    transformations = []
    for _ in range(4):  # 4 поворота
        min_x = min(x for x, y in shape)
        min_y = min(y for x, y in shape)
        normalized = sorted((x - min_x, y - min_y) for x, y in shape)
        transformations.append(tuple(normalized))
        # Поворот
        shape = [(y, -x) for x, y in shape]
    # Отражения
    for reflection in [1, -1]:
        reflected = [(x, y * reflection) for x, y in shape]
        for _ in range(4):
            min_x = min(x for x, y in reflected)
            min_y = min(y for x, y in reflected)
            normalized = sorted((x - min_x, y - min_y) for x, y in reflected)
            transformations.append(tuple(normalized))
            reflected = [(y, -x) for x, y in reflected]
    return min(transformations)

def is_valid(x, y, n, grid):
    """Проверяет, можно ли использовать клетку."""
    return 0 <= x < n and 0 <= y < n and grid[x][y] == 0

def bfs_fill(x, y, n, id, grid):
    """Создает одну n-миношку с использованием BFS."""
    shape = []
    queue = deque([(x, y)])
    grid[x][y] = id
    shape.append((x, y))
    directions = [(-1, 0), (1, 0), (0, -1), (0, 1)]
    
    while queue and len(shape) < n:
        cx, cy = queue.popleft()
        for dx, dy in directions:
            nx, ny = cx + dx, cy + dy
            if is_valid(nx, ny, n, grid):
                grid[nx][ny] = id
                shape.append((nx, ny))
                queue.append((nx, ny))
    return shape if len(shape) == n else None

def solve(n):
    if n == 1:
        return [[1]]
    if n % 2 == 1:
        return -1

    grid = [[0] * n for _ in range(n)]
    used_shapes = set()
    id = 1

    for i in range(n):
        for j in range(n):
            if grid[i][j] == 0:
                shape = bfs_fill(i, j, n, id, grid)
                if shape is None:
                    return -1
                normalized_shape = normalize(shape)
                if normalized_shape in used_shapes:
                    return -1
                used_shapes.add(normalized_shape)
                id += 1

    return grid

# Ввод и вывод
n = int(input())
result = solve(n)
if result == -1:
    print(-1)
else:
    for row in result:
        print(" ".join(map(str, row)))
