from collections import defaultdict

class Graph:
    def __init__(self, n):
        self.n = n
        self.edges = defaultdict(set)
        self.vertex_degree = defaultdict(lambda: defaultdict(int))
        self.color_beauty = defaultdict(int)
        self.total_beauty = 0

    def add_edge(self, v, u, c):
        v, u = min(v, u), max(v, u)

        self.edges[c].add((v, u))
        self.vertex_degree[c][v] += 1
        self.vertex_degree[c][u] += 1

        if self.vertex_degree[c][v] == 1 and self.vertex_degree[c][u] == 1:
            if self.color_beauty[c] == 0:
                self.total_beauty += 1
            self.color_beauty[c] += 1
        elif self.vertex_degree[c][v] == 2 or self.vertex_degree[c][u] == 2:
            if self.color_beauty[c] > 0:
                self.color_beauty[c] -= 1
                self.total_beauty -= 1

    def remove_edge(self, v, u, c):
        v, u = min(v, u), max(v, u)

        self.edges[c].remove((v, u))
        self.vertex_degree[c][v] -= 1
        self.vertex_degree[c][u] -= 1

        if self.vertex_degree[c][v] == 1 and self.vertex_degree[c][u] == 1:
            if self.color_beauty[c] == 0:
                self.total_beauty += 1
            self.color_beauty[c] += 1
        elif self.vertex_degree[c][v] == 0 or self.vertex_degree[c][u] == 0:
            if self.color_beauty[c] > 0:
                self.color_beauty[c] -= 1
                self.total_beauty -= 1

    def get_total_beauty(self):
        return self.total_beauty

def process_queries(n, queries):
    graph = Graph(n)
    result = []

    for query in queries:
        parts = query.split()
        if parts[0] == "+":
            v, u, c = int(parts[1]), int(parts[2]), int(parts[3])
            graph.add_edge(v, u, c)
        elif parts[0] == "-":
            v, u, c = int(parts[1]), int(parts[2]), int(parts[3])
            graph.remove_edge(v, u, c)

        result.append(graph.get_total_beauty())

    return result

n = 4
q = 5
queries = [
    "+ 1 2 1",
    "+ 3 4 2",
    "+ 2 4 1",
    "- 2 1 1",
    "+ 2 4 4"
]
result = process_queries(n, queries)
print("\n".join(map(str, result)))

n = 3
q = 6
queries = [
    "+ 1 2 1",
    "+ 2 3 1",
    "+ 1 3 1",
    "- 1 3 1",
    "- 1 2 1",
    "+ 1 2 1"
]
result = process_queries(n, queries)
print("\n".join(map(str, result)))