from collections import defaultdict

def process_queries(n, q, queries):
    edges_by_color = defaultdict(set)  # Stores edges by color
    degree_by_color = defaultdict(int)  # Stores degree for each color and vertex pair
    total_beauty = 0
    excellent_colors = set()  # Tracks excellent colors
    
    results = []
    
    # Helper function to determine if a color is excellent
    def update_excellent(c, v, u):
        nonlocal total_beauty
        if all(degree_by_color[(c, vertex)] <= 1 for vertex in (v, u)):
            if c not in excellent_colors:
                excellent_colors.add(c)
                total_beauty += len(edges_by_color[c])  # Add edges count to beauty
        else:
            if c in excellent_colors:
                excellent_colors.remove(c)
                total_beauty -= len(edges_by_color[c])  # Subtract edges count from beauty

    for query in queries:
        op, v, u, c = query
        if op == '+':
            # Add edge (v, u) of color c
            edges_by_color[c].add((v, u))
            degree_by_color[(c, v)] += 1
            degree_by_color[(c, u)] += 1
            update_excellent(c, v, u)

        elif op == '-':
            # Remove edge (v, u) of color c only if it exists
            if (v, u) in edges_by_color[c]:
                edges_by_color[c].remove((v, u))
                degree_by_color[(c, v)] -= 1
                degree_by_color[(c, u)] -= 1
                update_excellent(c, v, u)

        results.append(total_beauty)

    return results


n, q = map(int, input().split())
queries = [input().split() for _ in range(q)]
queries = [(op, int(v), int(u), int(c)) for op, v, u, c in queries]

results = process_queries(n, q, queries)

print('\n'.join(map(str, results)))