from collections import deque

DIRECTIONS = [(-1, 0), (0, 1), (1, 0), (0, -1)]
def generate_symmetries(figure):
    """ Возвращает все возможные симметричные формы фигуры: повороты и отражения. """
    def rotate(figure):
        return {(y, -x) for x, y in figure}

    def reflect(figure):
        return {(-x, y) for x, y in figure}

    def normalize(figure):
        min_x = min(x for x, y in figure)
        min_y = min(y for x, y in figure)
        return {(x - min_x, y - min_y) for x, y in figure}

    symmetries = set()

    current = set(figure)
    for _ in range(4):
        current = rotate(current)
        symmetries.add(frozenset(normalize(current)))
        symmetries.add(frozenset(normalize(reflect(current))))
    
    return symmetries

def find_all_figures(n):
    """ Находит все связные n-миношки. """
    def bfs(start_x, start_y):
        queue = deque([(start_x, start_y)])
        visited = set([(start_x, start_y)])
        figure = set([(start_x, start_y)])

        while queue:
            x, y = queue.popleft()
            for dx, dy in DIRECTIONS:
                nx, ny = x + dx, y + dy
                if (nx, ny) not in visited and 0 <= nx < n and 0 <= ny < n:
                    visited.add((nx, ny))
                    figure.add((nx, ny))
                    queue.append((nx, ny))
        return figure

    all_figures = set()

    for i in range(n):
        for j in range(n):
            figure = bfs(i, j)
            all_figures.add(frozenset(generate_symmetries(figure)))

    return all_figures

def solve(n):
    if n == 1:
        print(1)
        return

    if n == 4:
        print(-1)
        return

    figures = find_all_figures(n)
    for fig in figures:
        print(fig)

n = int(input())
solve(n)
